==> kadaster-gds2-1.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20120901/AfgifteType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20120901;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20120901.AfgifteGBType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.bestand.v20120901.Bestand;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.kenmerken.v20120901.BestandKenmerkenType;


/**
 * <p>Java class for AfgifteType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AfgifteType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="afgifteID">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;maxLength value="36"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element name="afgiftereferentie" minOccurs="0">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;minLength value="1"/>
 *               &lt;maxLength value="1024"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20120901}Bestand"/>
 *         &lt;element name="beschikbaarTot" type="{http://www.w3.org/2001/XMLSchema}dateTime"/>
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20120901}BestandKenmerken" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteType", propOrder = {
    "afgifteID",
    "afgiftereferentie",
    "bestand",
    "beschikbaarTot",
    "bestandKenmerken"
})
@XmlSeeAlso({
    AfgifteGBType.class
})
public class AfgifteType {

    @XmlElement(required = true)
    protected String afgifteID;
    protected String afgiftereferentie;
    @XmlElement(name = "Bestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20120901", required = true)
    protected Bestand bestand;
    @XmlElement(required = true)
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar beschikbaarTot;
    @XmlElement(name = "BestandKenmerken", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20120901")
    protected BestandKenmerkenType bestandKenmerken;

    /**
     * Gets the value of the afgifteID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgifteID() {
        return afgifteID;
    }

    /**
     * Sets the value of the afgifteID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgifteID(String value) {
        this.afgifteID = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

    /**
     * Gets the value of the bestand property.
     * 
     * @return
     *     possible object is
     *     {@link Bestand }
     *     
     */
    public Bestand getBestand() {
        return bestand;
    }

    /**
     * Sets the value of the bestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link Bestand }
     *     
     */
    public void setBestand(Bestand value) {
        this.bestand = value;
    }

    /**
     * Gets the value of the beschikbaarTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getBeschikbaarTot() {
        return beschikbaarTot;
    }

    /**
     * Sets the value of the beschikbaarTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setBeschikbaarTot(XMLGregorianCalendar value) {
        this.beschikbaarTot = value;
    }

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20120901/AfgifteType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20120901;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.datatype.XMLGregorianCalendar;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstgbresultaat.afgifte.v20120901.AfgifteGBType;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.bestand.v20120901.Bestand;
import nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.kenmerken.v20120901.BestandKenmerkenType;


/**
 * &lt;p&gt;Java class for AfgifteType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="AfgifteType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element name="afgifteID"&amp;gt;
 *           &amp;lt;simpleType&amp;gt;
 *             &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&amp;gt;
 *               &amp;lt;maxLength value="36"/&amp;gt;
 *             &amp;lt;/restriction&amp;gt;
 *           &amp;lt;/simpleType&amp;gt;
 *         &amp;lt;/element&amp;gt;
 *         &amp;lt;element name="afgiftereferentie" minOccurs="0"&amp;gt;
 *           &amp;lt;simpleType&amp;gt;
 *             &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&amp;gt;
 *               &amp;lt;minLength value="1"/&amp;gt;
 *               &amp;lt;maxLength value="1024"/&amp;gt;
 *             &amp;lt;/restriction&amp;gt;
 *           &amp;lt;/simpleType&amp;gt;
 *         &amp;lt;/element&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20120901}Bestand"/&amp;gt;
 *         &amp;lt;element name="beschikbaarTot" type="{http://www.w3.org/2001/XMLSchema}dateTime"/&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20120901}BestandKenmerken" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AfgifteType", propOrder = {
    "afgifteID",
    "afgiftereferentie",
    "bestand",
    "beschikbaarTot",
    "bestandKenmerken"
})
@XmlSeeAlso({
    AfgifteGBType.class
})
public class AfgifteType {

    @XmlElement(required = true)
    protected String afgifteID;
    protected String afgiftereferentie;
    @XmlElement(name = "Bestand", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/bestand/v20120901", required = true)
    protected Bestand bestand;
    @XmlElement(required = true)
    @XmlSchemaType(name = "dateTime")
    protected XMLGregorianCalendar beschikbaarTot;
    @XmlElement(name = "BestandKenmerken", namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/kenmerken/v20120901")
    protected BestandKenmerkenType bestandKenmerken;

    /**
     * Gets the value of the afgifteID property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgifteID() {
        return afgifteID;
    }

    /**
     * Sets the value of the afgifteID property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgifteID(String value) {
        this.afgifteID = value;
    }

    /**
     * Gets the value of the afgiftereferentie property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAfgiftereferentie() {
        return afgiftereferentie;
    }

    /**
     * Sets the value of the afgiftereferentie property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAfgiftereferentie(String value) {
        this.afgiftereferentie = value;
    }

    /**
     * Gets the value of the bestand property.
     * 
     * @return
     *     possible object is
     *     {@link Bestand }
     *     
     */
    public Bestand getBestand() {
        return bestand;
    }

    /**
     * Sets the value of the bestand property.
     * 
     * @param value
     *     allowed object is
     *     {@link Bestand }
     *     
     */
    public void setBestand(Bestand value) {
        this.bestand = value;
    }

    /**
     * Gets the value of the beschikbaarTot property.
     * 
     * @return
     *     possible object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public XMLGregorianCalendar getBeschikbaarTot() {
        return beschikbaarTot;
    }

    /**
     * Sets the value of the beschikbaarTot property.
     * 
     * @param value
     *     allowed object is
     *     {@link XMLGregorianCalendar }
     *     
     */
    public void setBeschikbaarTot(XMLGregorianCalendar value) {
        this.beschikbaarTot = value;
    }

    /**
     * Gets the value of the bestandKenmerken property.
     * 
     * @return
     *     possible object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public BestandKenmerkenType getBestandKenmerken() {
        return bestandKenmerken;
    }

    /**
     * Sets the value of the bestandKenmerken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandKenmerkenType }
     *     
     */
    public void setBestandKenmerken(BestandKenmerkenType value) {
        this.bestandKenmerken = value;
    }

}
